==> haskell-constraints-0.8-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.8
id: constraints-0.8-KMghHLStkTCAXaiizrSlFk
key: constraints-0.8-KMghHLStkTCAXaiizrSlFk
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Unsafe
abi: f44265689c48e9a36a51ae324be46a8e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.8
data-dir: /usr/share/arm-linux-ghc-8.0.1/constraints-0.8
hs-libraries: HSconstraints-0.8-KMghHLStkTCAXaiizrSlFk
depends:
    base-4.9.0.0 binary-0.8.3.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-0.8-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.8
id: constraints-0.8-6ebQqOtc5gnCoSa30ACr1e
key: constraints-0.8-6ebQqOtc5gnCoSa30ACr1e
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Unsafe
abi: 87330576bc88b9d960f19ce7f6fad522
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.8
data-dir: /usr/share/arm-linux-ghc-8.0.1/constraints-0.8
hs-libraries: HSconstraints-0.8-6ebQqOtc5gnCoSa30ACr1e
depends:
    base-4.9.0.0 binary-0.8.3.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
